function [Q,Z] = findsos(p)
% FINDSOS --- Find a sum of squares decomposition of a given polynomial.
%
% [Q,Z] = findsos(P)
%
% P is a scalar polynomial.
% A positive semidefinite Q and a symbolic monomial vector Z will be 
% computed such that
% 
%    Z' * Q * Z = P
%
% If P is not a sum of squares, the function will return empty Q and Z.
%


% This file is part of SOSTOOLS - Sum of Squares Toolbox ver 1.00.
%
% Copyright (C) 2002  S. Prajna (1), A. Papachristodoulou (1), P. A. Parrilo (2)
% (1) Control and Dynamical Systems - California Institute of Technology,
%     Pasadena, CA 91125, USA.
% (2) Institut fur Automatik - ETH Zurich, CH-8092 Zurich, Switzerland.
%
% Send feedback to: sostools@cds.caltech.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%


% 12/27/01 - SP
% 03/27/02 - SP

vars = findsym(p);
vars = sym(['[',vars,']']);

nvars = size(vars,2) ; 

% Can change, to call maple only once.
for var = 1:nvars;
    if rem(double(maple('degree',p,vars(var))),2) ;
    disp(['Degree in ' char(vars(var)) ' is not even. The polynomial cannot be a sum of squares']);
    Q = [];
    Z = [];
    return;
    end;
end;

prog = sosprogram(vars);
prog = sosineq(prog,p);
[prog,info] = sossolve(prog);

if (info.dinf==1)|(info.pinf==1)
    disp('No sum of squares decomposition is found.');
    Q = [];
    Z = [];
else
    Q = mat(prog.solinfo.RRx);
    Z = mysympower(vars,prog.extravar.Z{1});
end;

