function [sos,V] = sossosvar(sos,ZSym,wscoeff)
% SOSSOSVAR --- Declare a new sum of squares variable in 
%       an SOS program 
%
% [SOSP,VAR] = sossosvar(SOSP,Z)
%
% SOSP is the sum of squares program.
% VAR is the new sum of squares variable.
% Z is the column vector of monomials contained in the Gram 
% decomposition of VAR, i.e.,
%
%       VAR = Z' * COEFF * Z
%
% where COEFF is a coefficient matrix that is restricted to be 
% positive semidefinite. COEFF and the decision variables contained 
% in it will be constructed automatically by SOSSOSVAR.
%
% Both VAR and Z are symbolic objects.
%
% [SOSP,VAR] = sospolyvar(SOSP,Z,'wscoeff') will create
% the decision variables corresponding to VAR (i.e., coeff_xxx)
% also in MATLAB workspace.
%

% This file is part of SOSTOOLS - Sum of Squares Toolbox ver 1.00.
%
% Copyright (C) 2002  S. Prajna (1), A. Papachristodoulou (1), P. A. Parrilo (2)
% (1) Control and Dynamical Systems - California Institute of Technology,
%     Pasadena, CA 91125, USA.
% (2) Institut fur Automatik - ETH Zurich, CH-8092 Zurich, Switzerland.
%
% Send feedback to: sostools@cds.caltech.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%

if isnumeric(ZSym) & ZSym == 1
    ZSym = sym(ZSym);
end;
[sos,V] = sosvar(sos,'sos',ZSym);

if nargin > 2 & wscoeff == 'wscoeff'
    var = sos.var.num;
    for i = sos.var.idx{var}:sos.var.idx{var+1}-1
        assignin('base',['coeff_',int2str(i-sos.var.idx{1}+1)],sos.symdecvartable(i));
    end;
end;